@@ -259,62 +259,62 @@ void Settings::GetProgram(QString file)
 
 void Settings::on_pushButton_clicked()
 {
-    Items* it = new Items(this,0);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,0);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_2_clicked()
 {
-    Items* it = new Items(this,1);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,1);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_3_clicked()
 {
-    Items* it = new Items(this,2);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,2);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_4_clicked()
 {
-    Items* it = new Items(this,3);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,3);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_5_clicked()
 {
-    Items* it = new Items(this,4);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,4);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_6_clicked()
 {
-    Items* it = new Items(this,5);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,5);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_7_clicked()
 {
-    Items* it = new Items(this,6);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,6);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_8_clicked()
 {
-    Items* it = new Items(this,7);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,7);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_9_clicked()
 {
-    Items* it = new Items(this,8);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,8);
+    it->exec(); it->close(); LoadAll();
 }
 
 void Settings::on_pushButton_10_clicked()
 {
-    Items* it = new Items(this,9);
-    it->exec(); LoadAll();
+    Items* it = new Items(0,9);
+    it->exec(); it->close(); LoadAll();
 }
 
 
