@@ -19,29 +19,24 @@ class Widget : public QeMaemo5DynamicHomescreenWidget
 {
     Q_OBJECT
 public:
+    static Widget *createAndShowNew();
+
     explicit Widget(QWidget *parent = 0);
+    ~Widget();
+
 
 public slots:
     void GetProg (QString file);
     void showSettingsDialog();
     void loadProgs();
-    void desktop1();
-    void desktop2();
-    void desktop3();
-    void desktop4();
-    void desktop5();
-    void desktop6();
-    void desktop7();
-    void desktop8();
-    void desktop9();
-    void desktop10();
 
 private:
     QGridLayout *layout;
-    QToolButton *buttons[9];
 
 protected:
-    virtual void paintEvent(QPaintEvent *e);
+    void mousePressEvent (QMouseEvent *ev);
+    void paintEvent(QPaintEvent *event);
+    bool restoreWidgetState();
 
 };
 
